@@ -7,10 +7,10 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-# ABSTRACT: Fix the configuration of an application
+# ABSTRACT: Run a cme script
 
 package App::Cme::Command::run ;
-$App::Cme::Command::run::VERSION = '1.018';
+$App::Cme::Command::run::VERSION = '1.019';
 use strict;
 use warnings;
 use 5.10.1;
@@ -59,10 +59,10 @@ sub description {
 }
 
 sub execute {
-    my ($self, $opt, $args) = @_;
+    my ($self, $opt, $app_args) = @_;
 
     # see Debian #839593 and perlunicook(1) section X 13
-    @$args = map { decode_utf8($_, 1) } @$args;
+    @$app_args = map { decode_utf8($_, 1) } @$app_args;
 
     if ($opt->{list}) {
         my @scripts;
@@ -75,7 +75,7 @@ sub execute {
         return;
     }
 
-    my $script_name = shift @$args;
+    my $script_name = shift @$app_args;
     my $script;
 
     if ($script_name =~ m!/!) {
@@ -95,7 +95,7 @@ sub execute {
     my $content = $script->slurp_utf8;
 
     # parse variables passed on command line
-    my %fill_h = map { split '=',$_,2; } @{ $opt->{arg} };
+    my %user_args = map { split '=',$_,2; } @{ $opt->{arg} };
 
     if ($content =~ m/^#!/ or $content =~ /^use/m) {
         splice @ARGV, 0,2; # remove 'run script' arguments
@@ -107,15 +107,20 @@ sub execute {
     my %var;
 
     # find if all variables are accounted for
-    my @missing ;
+    my %missing ;
+
+    # %args can be used in var ssection of a script. A new entry in
+    # added in %missing if the script tries to read an undefined value
+    tie my %args, 'App::Cme::Run::Var', \%missing;
+    %args = %user_args;
 
     # replace variables with command arguments or eval'ed variables or env variables
     my $replace_var = sub {
         # change $var but not \$var
-        $_[0] =~ s~ (?<!\\) \$(\w+) ~ $fill_h{$1} // $var{$1} // $ENV{$1} // '$'.$1~xeg;
+        $_[0] =~ s~ (?<!\\) \$(\w+) (?!\s*{) ~ $user_args{$1} // $var{$1} // $ENV{$1} // '$'.$1~xeg;
 
         # register vars without replacements
-        push @missing, ($_[0] =~ m~ (?<!\\) \$(\w+) ~xg);
+        map { $missing{$_} = 1 ;} ($_[0] =~ m~ (?<!\\) \$(\w+) ~xg);
 
         # now change \$var in $var
         $_[0] =~ s!\\\$!\$!g;
@@ -140,7 +145,7 @@ sub execute {
         $replace_var->($value) unless $key eq 'var';
 
         if ($key =~ /^app/) {
-            unshift @$args, $value;
+            unshift @$app_args, $value;
         }
         elsif ($key eq 'var') {
             eval ($value) ;
@@ -165,12 +170,12 @@ sub execute {
         return;
     }
 
-    if (@missing) {
-        die "Error: Missing variables @missing in command arguments for script $script\n"
-            ."Please use option '-arg ".join(',', map { "$_=xxx"} @missing)."'\n";
+    if (my @missing = sort keys %missing) {
+        die "Error: Missing variables '". join("', '",@missing)."' in command arguments for script $script\n"
+            ."Please use option '".join(' ', map { "-arg $_=xxx"} @missing)."'\n";
     }
 
-    $self->process_args($opt, $args);
+    $self->process_args($opt, $app_args);
 
     # check if workspace and index are clean
     if ($commit_msg) {
@@ -180,7 +185,7 @@ sub execute {
     }
 
     # call loads
-    my ($model, $inst, $root) = $self->init_cme($opt,$args);
+    my ($model, $inst, $root) = $self->init_cme($opt,$app_args);
     map { $root->load($_) } @load;
 
     $self->save($inst,$opt) ;
@@ -191,6 +196,19 @@ sub execute {
     }
 }
 
+package App::Cme::Run::Var;
+$App::Cme::Run::Var::VERSION = '1.019';
+require Tie::Hash;
+
+our @ISA = qw(Tie::ExtraHash);
+
+sub FETCH {
+    my ($self, $key) = @_ ;
+    my ($h,$missing) = @$self;
+    $missing->{$key} = 1 unless defined $h->{$key};
+    return $h->{$key} // '';
+}
+
 1;
 
 __END__
@@ -201,11 +219,11 @@ __END__
 
 =head1 NAME
 
-App::Cme::Command::run - Fix the configuration of an application
+App::Cme::Command::run - Run a cme script
 
 =head1 VERSION
 
-version 1.018
+version 1.019
 
 =head1 SYNOPSIS
 
@@ -307,6 +325,10 @@ code must store data in C<%var> hash. For instance:
 
     perl: my @l = localtime; $var{year} =  $l[5]+1900;
 
+The hash C<%args> contains the variables passed with the C<-arg>
+option. Reading a value from C<%args> which is set by the user
+triggers an error.
+
 =item load
 
 Specify the modifications to apply using a string as specified in
